@@ -38,6 +38,18 @@ class ListInstanceIndicesRequest(RoaRequest):
 	def set_InstanceId(self,InstanceId):
 		self.add_path_param('InstanceId',InstanceId)
 
+	def get_isManaged(self):
+		return self.get_query_params().get('isManaged')
+
+	def set_isManaged(self,isManaged):
+		self.add_query_param('isManaged',isManaged)
+
+	def get_name(self):
+		return self.get_query_params().get('name')
+
+	def set_name(self,name):
+		self.add_query_param('name',name)
+
 	def get_lang(self):
 		return self.get_query_params().get('lang')
 
